@@ -17,7 +17,7 @@
     under the License.
 */
 
-const fs = require('fs');
+const fs = require('node:fs');
 const xml = require('cordova-common').xmlHelpers;
 
 const DEFAULT_ORIENTATION = 'default';
