@@ -17,7 +17,7 @@
     under the License.
 */
 
-const path = require('path');
+const path = require('node:path');
 
 const AndroidProject = require('./AndroidProject');
 const PluginManager = require('cordova-common').PluginManager;
@@ -277,6 +277,12 @@ class Api {
         });
     }
 
+    listTargets (options) {
+        return require('./check_reqs').check_android().then(() => {
+            return require('./run').runListDevices.call(this, options);
+        });
+    }
+
     /**
      * Cleans out the build artifacts from platform's directory, and also
      * cleans out the platform www directory if called without options specified.
