@@ -18,8 +18,8 @@
 */
 
 const execa = require('execa');
-const fs = require('fs-extra');
-const path = require('path');
+const fs = require('node:fs');
+const path = require('node:path');
 const glob = require('fast-glob');
 const { CordovaError, events } = require('cordova-common');
 const utils = require('../utils');
@@ -98,7 +98,7 @@ const java = {
                     }
                 } else {
                     // See if we can derive it from javac's location.
-                    var maybeJavaHome = path.dirname(path.dirname(javacPath));
+                    const maybeJavaHome = path.dirname(path.dirname(javacPath));
                     if (fs.existsSync(path.join(maybeJavaHome, 'bin', 'java')) ||
                             fs.existsSync(path.join(maybeJavaHome, 'bin', 'java.exe'))) {
                         environment.JAVA_HOME = maybeJavaHome;
