@@ -17,8 +17,8 @@
     under the License.
 */
 
-const fs = require('fs-extra');
-const path = require('path');
+const fs = require('node:fs');
+const path = require('node:path');
 const nopt = require('nopt');
 const glob = require('fast-glob');
 const dedent = require('dedent');
@@ -93,7 +93,7 @@ function updateUserProjectGradleConfig (project) {
 
     // Write out changes
     const projectGradleConfigPath = path.join(project.root, 'cdv-gradle-config.json');
-    fs.writeJSONSync(projectGradleConfigPath, projectGradleConfig, { spaces: 2 });
+    fs.writeFileSync(projectGradleConfigPath, JSON.stringify(projectGradleConfig, null, 2), 'utf-8');
 }
 
 function getUserGradleConfig (configXml) {
@@ -198,7 +198,7 @@ function updateConfigFilesFrom (sourceConfig, configMunger, locations) {
 
     // First cleanup current config and merge project's one into own
     // Overwrite platform config.xml with defaults.xml.
-    fs.copySync(locations.defaultConfigXml, locations.configXml);
+    fs.cpSync(locations.defaultConfigXml, locations.configXml);
 
     // Then apply config changes from global munge to all config files
     // in project (including project's config)
@@ -271,7 +271,7 @@ function cleanWww (projectRoot, locations) {
  */
 function updateProjectAccordingTo (platformConfig, locations) {
     updateProjectStrings(platformConfig, locations);
-    updateProjectSplashScreen(platformConfig, locations);
+    updateProjectTheme(platformConfig, locations);
 
     const name = platformConfig.name();
 
@@ -316,14 +316,14 @@ function updateProjectAccordingTo (platformConfig, locations) {
     const newDestFile = path.join(locations.root, 'app', 'src', 'main', 'java', androidPkgName.replace(/\./g, '/'), path.basename(destFile));
     if (newDestFile.toLowerCase() !== destFile.toLowerCase()) {
         // If package was name changed we need to create new java with main activity in path matching new package name
-        fs.ensureDirSync(path.dirname(newDestFile));
+        fs.mkdirSync(path.dirname(newDestFile), { recursive: true });
         events.emit('verbose', `copy ${destFile} to ${newDestFile}`);
-        fs.copySync(destFile, newDestFile);
+        fs.cpSync(destFile, newDestFile);
         utils.replaceFileContents(newDestFile, /package [\w.]*;/, 'package ' + androidPkgName + ';');
         events.emit('verbose', 'Wrote out Android package name "' + androidPkgName + '" to ' + newDestFile);
         // If package was name changed we need to remove old java with main activity
         events.emit('verbose', `remove ${destFile}`);
-        fs.removeSync(destFile);
+        fs.rmSync(destFile);
         // remove any empty directories
         let currentDir = path.dirname(destFile);
         const sourcesRoot = path.resolve(locations.root, 'src');
@@ -376,11 +376,31 @@ function warnForDeprecatedSplashScreen (cordovaProject) {
  *   be used to update project
  * @param   {Object}  locations       A map of locations for this platform
  */
-function updateProjectSplashScreen (platformConfig, locations) {
+function updateProjectTheme (platformConfig, locations) {
     // res/values/themes.xml
     const themes = xmlHelpers.parseElementtreeSync(locations.themes);
     const splashScreenTheme = themes.find('style[@name="Theme.App.SplashScreen"]');
 
+    // Update edge-to-edge settings in app theme.
+    let hasE2E = false; // default case
+
+    const preferenceE2E = platformConfig.getPreference('AndroidEdgeToEdge', this.platform);
+    if (!preferenceE2E) {
+        events.emit('verbose', 'The preference name "AndroidEdgeToEdge" was not set. Defaulting to "false".');
+    } else {
+        const hasInvalidPreferenceE2E = preferenceE2E !== 'true' && preferenceE2E !== 'false';
+        if (hasInvalidPreferenceE2E) {
+            events.emit('verbose', 'Preference name "AndroidEdgeToEdge" has an invalid value. Valid values are "true" or "false". Defaulting to "false"');
+        }
+        hasE2E = hasInvalidPreferenceE2E ? false : preferenceE2E === 'true';
+    }
+
+    const optOutE2EKey = 'android:windowOptOutEdgeToEdgeEnforcement';
+    const optOutE2EItem = splashScreenTheme.find(`item[@name="${optOutE2EKey}"]`);
+    const optOutE2EValue = !hasE2E ? 'true' : 'false';
+    optOutE2EItem.text = optOutE2EValue;
+    events.emit('verbose', `Updating theme item "${optOutE2EKey}" with value "${optOutE2EValue}"`);
+
     let splashBg = platformConfig.getPreference('AndroidWindowSplashScreenBackground', this.platform);
     if (!splashBg) {
         splashBg = platformConfig.getPreference('SplashScreenBackgroundColor', this.platform);
@@ -397,6 +417,7 @@ function updateProjectSplashScreen (platformConfig, locations) {
     splashBgNode.text = '@color/cdv_splashscreen_background';
 
     [
+        // Splash Screen
         'windowSplashScreenAnimatedIcon',
         'windowSplashScreenAnimationDuration',
         'android:windowSplashScreenBrandingImage',
@@ -536,16 +557,16 @@ function updateProjectSplashScreenIconBackgroundColor (splashIconBackgroundColor
 
 function cleanupAndSetProjectSplashScreenImage (srcFile, destFilePath, possiblePreviousDestFilePath, cleanupOnly = false) {
     if (fs.existsSync(possiblePreviousDestFilePath)) {
-        fs.removeSync(possiblePreviousDestFilePath);
+        fs.rmSync(possiblePreviousDestFilePath);
     }
 
     if (cleanupOnly && fs.existsSync(destFilePath)) {
         // Also remove dest file path for cleanup even if previous was not use.
-        fs.removeSync(destFilePath);
+        fs.rmSync(destFilePath);
     }
 
     if (!cleanupOnly && srcFile && fs.existsSync(srcFile)) {
-        fs.copySync(srcFile, destFilePath);
+        fs.cpSync(srcFile, destFilePath);
     }
 }
 
